function sector_bound,theta0,theta1,x,y,nx,ny

;+
; NAME
;	sector_bound
; PURPOSE
;	  To return the vector of indices for a sector of angular
;	width theta1-theta0, centered at x,y within a rectangular
;	array of dimensions nx,ny.
;	  If the sector includes one or more corners in the array 
;	the vector includes the area out to the corners.
; CALLING SEQUENCE
;	xy=sector_bound(theta0,theta1,x,y,nx,ny)
; INPUT
;	Measuring CW from up (north on CCD)
;	   theta0 - angle (degrees) defining small-angle boundary of sector
;	   theta1 - angle (degrees) defining large-angle boundary of sector
;	x, y, - coordinates of origin
;	nx, ny - dimensions of rectangular array
; OUTPUT
;	xy - vector of indices of pixels within sector
; RESTRICTIONS
;       Do not use a theta range greater than 180 degrees.
; HISTORY
;	LWA, 14-Jun-95, written for use in azimuth_avg.pro
;	LWA, 28-Nov-95, corrected error in (case 3:) equation.
;                       corrected error in (case 2:) equation.
;	LWA, 12-Apr-01, corrected and clarified header.
;-

mx=nx-1
my=ny-1

;  Find the corners

thetac=fltarr(4)

thetac(0)=atan(float(mx-x)/(my-y))*(180./!pi)
thetac(1)=180.+atan(float(mx-x)/(-y))*(180./!pi)
thetac(2)=180.+atan(float(-x)/(-y))*(180./!pi)
thetac(3)=360.+atan(float(-x)/(my-y))*(180./!pi)
;print,'thetac=',thetac

;  Select the appropiate theta range


theta=fltarr(2)
theta(0)=theta0
if theta(0) lt 0. then theta(0)=360.+theta(0)
if theta(0) gt 360. then theta(0)=theta(0)-360.
theta(1)=theta1
if theta(1) lt 0. then theta(1)=360.+theta(1)
if theta(1) gt 360. then theta(1)=theta(1)-360.

;print,'theta=',theta
;print,'x=',x,'  ','y=',y,'  ','mx=',mx,'  ','my=',my

;  Radial limits rr.
; rr(0,0) is end x coordinate of CCW boundary vector
; rr(1,0) is end y coordinate of CCW boundary vector
; rr(0,1) is end x coordinate of CW boundary vector
; rr(1,1) is end y coordinate of CW boundary vector
 
rr=intarr(2,2)
ij=bytarr(2)

;  Get the border limits for each side of the sector

for i=0,1 do begin

   ii=where(thetac gt theta(i),nii)
;print,'i=',i,'  ','theta(i)=',theta(i)
;print,'i=',i,'  ','nii=',nii,'  ','ii=',ii
   if nii eq 0 then ii=0 else ii=ii(0)
   ij(i)=ii
;print,'i=',i,'  ','ii=ij=',ij(i)

   case ii of   
      0:  begin
            rr(0,i)=fix(0.5+(x+(my-y)*tan(theta(i)*(!pi/180.))))
            rr(1,i)=my
;print,'rr(0,i)=',rr(0,i),'  ','rr(1,i)=',rr(1,i)
          end
      1:  begin
            rr(0,i)=mx
            rr(1,i)=fix(0.5+(y+(mx-x)*tan((!pi/2)-theta(i)*(!pi/180.))))
;print,'rr(0,i)=',rr(0,i),'  ','rr(1,i)=',rr(1,i)
          end
      2:  begin
            rr(0,i)=fix((x-y*tan(theta(i)*(!pi/180.)))+0.5)
            rr(1,i)=0
;print,'rr(0,i)=',rr(0,i),'  ','rr(1,i)=',rr(1,i)
          end
      3:  begin
            rr(0,i)=0
            rr(1,i)=fix(0.5+(y-(x*(tan((!pi/2)-theta(i)*(!pi/180.))))))
;print,'rr(0,i)=',rr(0,i),'  ','rr(1,i)=',rr(1,i)
          end
   else:  print,"ERROR in theta input!"
   endcase

endfor

if ij(0) eq ij(1) then begin

   xverts=[x,rr(0,0),rr(0,1)]
   yverts=[y,rr(1,0),rr(1,1)]
;print,'no corner
;print,'ij(0)=',IJ(0),'  ','ij(1)=',ij(1)
;print,xverts,yverts

endif else begin
   corns=intarr(2,4)
   corns(*,0)=[mx,my]
   corns(*,1)=[mx,0]
   corns(*,2)=[0,0]
   corns(*,3)=[0,my]

   xverts=[x,rr(0,0),corns(0,ij(0)),corns(0,ij(1)),rr(0,1)]
   yverts=[y,rr(1,0),corns(1,ij(0)),corns(1,ij(1)),rr(1,1)]
;print,'CORNER!
;print,'ij(0)=',IJ(0),'  ','ij(1)=',ij(1)
;print,xverts,yverts

endelse

xy=polyfillv(xverts,yverts,nx,ny)

return,xy

end
